@@ -5,15 +5,25 @@ from operator import itemgetter
 
 from sql.operators import Concat
 
+from trytond.i18n import gettext
+from trytond.model import ModelView
 from trytond.pool import PoolMeta, Pool
 from trytond.transaction import Transaction
 from trytond.tools import grouped_slice, reduce_ids
 
-__all__ = ['Move']
+from trytond.modules.account.exceptions import PostError
 
 
-class Move:
-    __metaclass__ = PoolMeta
+class Journal(metaclass=PoolMeta):
+    __name__ = 'account.journal'
+
+    @classmethod
+    def __setup__(cls):
+        super(Journal, cls).__setup__()
+        cls.type.selection.append(('statement', "Statement"))
+
+
+class Move(metaclass=PoolMeta):
     __name__ = 'account.move'
 
     @classmethod
@@ -35,7 +45,7 @@ class Move:
                     )
                 ).select(sql_table.id, statement_line.statement,
                 order_by=(sql_table.id, statement_line.statement)))
-        for statement_id, values in groupby(cursor.fetchall(), itemgetter(1)):
+        for statement_id, values in groupby(cursor, itemgetter(1)):
             ids = [x[0] for x in values]
             for sub_ids in grouped_slice(ids):
                 red_sql = reduce_ids(sql_table.id, sub_ids)
@@ -47,3 +57,25 @@ class Move:
     @classmethod
     def _get_origin(cls):
         return super(Move, cls)._get_origin() + ['account.statement']
+
+    @classmethod
+    @ModelView.button
+    def post(cls, moves):
+        pool = Pool()
+        Statement = pool.get('account.statement')
+        for move in moves:
+            if (isinstance(move.origin, Statement)
+                    and move.origin.state != 'posted'):
+                raise PostError(
+                    gettext('account_statement.msg_post_statement_move',
+                        move=move.rec_name,
+                        statement=move.origin.rec_name))
+        super().post(moves)
+
+
+class MoveLine(metaclass=PoolMeta):
+    __name__ = 'account.move.line'
+
+    @classmethod
+    def _get_origin(cls):
+        return super()._get_origin() + ['account.statement.line']
